"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RULE_NAME = void 0;
const node_utils_1 = require("../node-utils");
const create_testing_library_rule_1 = require("../create-testing-library-rule");
exports.RULE_NAME = 'no-wait-for-multiple-assertions';
exports.default = create_testing_library_rule_1.createTestingLibraryRule({
    name: exports.RULE_NAME,
    meta: {
        type: 'suggestion',
        docs: {
            description: "It's preferred to avoid multiple assertions in `waitFor`",
            category: 'Best Practices',
            recommended: false,
        },
        messages: {
            noWaitForMultipleAssertion: 'Avoid using multiple assertions within `waitFor` callback',
        },
        fixable: null,
        schema: [],
    },
    defaultOptions: [],
    create: function (context, _, helpers) {
        function totalExpect(body) {
            return body.filter((node) => {
                const expressionIdentifier = node_utils_1.getPropertyIdentifierNode(node);
                if (!expressionIdentifier) {
                    return false;
                }
                return expressionIdentifier.name === 'expect';
            });
        }
        function reportMultipleAssertion(node) {
            const callExpressionNode = node.parent.parent;
            const callExpressionIdentifier = node_utils_1.getPropertyIdentifierNode(callExpressionNode);
            if (!helpers.isAsyncUtil(callExpressionIdentifier, ['waitFor'])) {
                return;
            }
            if (totalExpect(node.body).length <= 1) {
                return;
            }
            context.report({
                node: callExpressionNode,
                messageId: 'noWaitForMultipleAssertion',
            });
        }
        return {
            'CallExpression > ArrowFunctionExpression > BlockStatement': reportMultipleAssertion,
            'CallExpression > FunctionExpression > BlockStatement': reportMultipleAssertion,
        };
    },
});
