"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RULE_NAME = void 0;
const node_utils_1 = require("../node-utils");
const create_testing_library_rule_1 = require("../create-testing-library-rule");
exports.RULE_NAME = 'no-wait-for-side-effects';
exports.default = create_testing_library_rule_1.createTestingLibraryRule({
    name: exports.RULE_NAME,
    meta: {
        type: 'suggestion',
        docs: {
            description: "It's preferred to avoid side effects in `waitFor`",
            category: 'Best Practices',
            recommended: false,
        },
        messages: {
            noSideEffectsWaitFor: 'Avoid using side effects within `waitFor` callback',
        },
        fixable: null,
        schema: [],
    },
    defaultOptions: [],
    create: function (context, _, helpers) {
        function hasSideEffects(body) {
            return body.some((node) => {
                const expressionIdentifier = node_utils_1.getPropertyIdentifierNode(node);
                if (!expressionIdentifier) {
                    return false;
                }
                return (helpers.isFireEventUtil(expressionIdentifier) ||
                    helpers.isUserEventUtil(expressionIdentifier));
            });
        }
        function reportSideEffects(node) {
            const callExpressionNode = node.parent.parent;
            const callExpressionIdentifier = node_utils_1.getPropertyIdentifierNode(callExpressionNode);
            if (!helpers.isAsyncUtil(callExpressionIdentifier, ['waitFor'])) {
                return;
            }
            if (!hasSideEffects(node.body)) {
                return;
            }
            context.report({
                node: callExpressionNode,
                messageId: 'noSideEffectsWaitFor',
            });
        }
        return {
            'CallExpression > ArrowFunctionExpression > BlockStatement': reportSideEffects,
            'CallExpression > FunctionExpression > BlockStatement': reportSideEffects,
        };
    },
});
